@@ -13,9 +13,9 @@ headers = {
     "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.87 Safari/537.36"
 }
 
-# 报错钉钉推送；
+# 钉钉推送；
 class DingDing_Push:
-    def __init__(self, push_title, *args, push_status='获取成功', now_time=str(datetime.datetime.now())[:19], push_url='https://oapi.dingtalk.com/robot/send?access_token=f3a590b8c5f4c4777fe0f217067f15132091bff53e2a2143a5daa981d795159d'):
+    def __init__(self, push_title, *args, push_status='执行成功', now_time=str(datetime.datetime.now())[:19], push_url='https://oapi.dingtalk.com/robot/send?access_token=f3a590b8c5f4c4777fe0f217067f15132091bff53e2a2143a5daa981d795159d'):
         self.push_title = push_title
         self.push_status = push_status
         self.now_time = now_time
@@ -180,7 +180,7 @@ class Qimai_Intside_Tool:
 
 # 常用的自定义参数；
 class Qimai_Diy_Var:
-    def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', search_type='all', brand='all', day=1, appRankShow=1, subclass='all', simple=1, rankEchartType=1, rankType='day', run_time=datetime.date.today(), status=6, keyword_hot_start=4605, typec='day', star='five', delete=-1, orderType='time', commentType='default', genre_type=36, status_type=3, clear_type=1, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc', option=4):
+    def __init__(self, country='cn', rank_type='all', version='ios12', device='iphone', search_type='all', brand='all', day=1, appRankShow=1, subclass='all', simple=1, rankEchartType=1, rankType='day', run_time=datetime.date.today(), status=6, keyword_hot_start=4605, typec='day', star='five', delete=-1, orderType='time', commentType='default', genre_type=36, status_type=3, clear_type=1, filter='offline', search_word='', export_type='rank_clear_words', sort_field='beforeClearNum', sort_type='desc', option=4, app_status_str='all', app_status_sdate='', app_status_edate='', app_status_order='', app_status_sort='', preOrder_order=1):
         self.country = country
         self.rank_type = rank_type
         self.version = version
@@ -211,6 +211,12 @@ class Qimai_Diy_Var:
         self.sort_field = sort_field
         self.sort_type = sort_type
         self.option = option
+        self.app_status_str = app_status_str
+        self.app_status_sdate = app_status_sdate
+        self.app_status_edate = app_status_edate
+        self.app_status_order = app_status_order
+        self.app_status_sort = app_status_sort
+        self.preOrder_order = preOrder_order
 
 # 获取基础信息相关数据；
 class Get_App_Appinfo(Qimai_Diy_Var):
@@ -266,17 +272,30 @@ class Get_App_SamePubApp(Get_App_Appinfo, Qimai_Diy_Var):
     def get_samePubApp(self):
         url = 'https://api.qimai.cn/app/samePubApp?appid=%s&country=%s' %(self.appid, self.country)
         res = session.get(url, headers=headers)
-        self.samePubApp = res.json()['samePubApps']
-        return self.samePubApp
+        self.app_samePubApp = res.json()['samePubApps']
+        return self.app_samePubApp
 
     def get_app_genid(self):
         self.get_samePubApp()
-        for info in self.samePubApp:
+        for info in self.app_samePubApp:
             if str(info['appInfo']['appId']) == str(self.appid):
                 self.app_total_genid = info['total']['brand']
                 self.app_class_genid = info['class']['brand']
                 return self.app_total_genid, self.app_class_genid
 
+    def samePubApp_sorce(self):
+        self.get_samePubApp()
+        cp_quanzhong_list = []
+        for x in self.app_samePubApp:
+            all_rank_num = x['total']['ranking']
+            all_rank_quanzhong = round(1 - int(all_rank_num) / 1500, 4)
+            if all_rank_quanzhong == 1:
+                cp_quanzhong_list.append(0)
+            else:
+                cp_quanzhong_list.append(all_rank_quanzhong)
+
+        return max(cp_quanzhong_list)
+
 # 获取关键词的相关数据；
 class Get_Keyword_Info(Qimai_Diy_Var):
     def __init__(self, keyword):
@@ -332,6 +351,19 @@ class Get_App_Keyword(Qimai_Diy_Var):
         self.json_df.columns = ['关键词ID', '关键词', '排名', '变动前排名', '排名变动值', '指数', '结果数', '未知1', '未知2']
         return self.json_df
 
+    def app_cover_regular(self):
+        self.get_keywordSummary()
+        for keywordSummary_info in self.app_keywordSummary['keywordSummary']:
+            title = keywordSummary_info['title']
+            if title == '合计':
+                all_keyword = keywordSummary_info['all']['num']
+                top3_keyword = keywordSummary_info['top3']['num']
+                top10_keyword = keywordSummary_info['top10']['num']
+                if int(all_keyword) >= 3000:
+                    return ['覆盖合格', all_keyword, top3_keyword, top10_keyword]
+                else:
+                    return ['覆盖不合格', all_keyword, top3_keyword, top10_keyword]
+
 # 获取产品评论的相关接口；
 class Get_App_Comment(Qimai_Diy_Var):
     def __init__(self, appid, start_time, end_time):
@@ -438,25 +470,111 @@ class Get_App_Offline_List(Qimai_Diy_Var):
                 break
         return self.app_offline_list
 
+# 获取预订App列表；
+class Get_PreOrder_AppList(Qimai_Diy_Var):
+    def __init__(self):
+        Qimai_Diy_Var.__init__(self)
+
+    def get_preOrder_applist(self):
+        self.preOrder_applist_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/rank/preOrder?genre=%s&country=%s&order=%s&page=%s' %(self.genre_type, self.country, self.preOrder_order, page_num)
+            res = session.get(url, headers=headers)
+            self.preOrder_applist_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['maxPage']:
+                break
+        return self.preOrder_applist_list
+
 # 获取产品被精品推荐及上热搜情况列表；
 class Get_App_Recommend(Qimai_Diy_Var):
     def __init__(self, appid):
         Qimai_Diy_Var.__init__(self)
         self.appid = appid
 
-    def app_featured(self):
+    def get_app_featured(self):
         url = 'https://api.qimai.cn/app/featured?country=%s&appid=%s' %(self.country, self.appid)
         res = session.get(url, headers=headers)
         self.app_featured = res.json()
         return self.app_featured
 
-    def app_engagement(self, start_time, end_time):
+    def get_app_engagement(self, start_time, end_time):
         url = 'https://api.qimai.cn/app/engagement'
         payload='app_id=%s&s_date=%s&e_date=%s' %(self.appid, start_time, end_time)
         res = session.post(url, data=payload, headers=headers)
         self.app_engagement = res.json()
         return self.app_engagement
 
+    def featured_match(self):
+        self.get_app_featured()
+        tuijian_num = len(self.app_featured['featured'])
+        if tuijian_num > 0:
+            return ['有推荐', tuijian_num]
+        else:
+            return ['无推荐', tuijian_num]
+
+# 获取App不同状态列表；
+class Get_App_Status(Qimai_Diy_Var):
+    def __init__(self, appid):
+        Qimai_Diy_Var.__init__(self)
+        self.appid = appid
+
+    def get_all_appStatusList(self):
+        self.app_status_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/app/appStatusList'
+            payload='appid=%s&country=%s&status=all&sdate=%s&edate=%s&page=1&order=%s&sort=%s' %(self.appid, self.country, self.app_status_sdate, self.app_status_edate, self.app_status_order, self.app_status_sort)
+            res = session.post(url, data=payload, headers=headers)
+            self.app_status_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['maxPage']:
+                break
+        return self.app_status_list
+
+    def get_status_appStatusList(self):
+        self.app_status_list = []
+        page_num = 1
+        while True:
+            url = 'https://api.qimai.cn/app/appStatusList'
+            payload='appid=%s&country=%s&status=%s&sdate=%s&edate=%s&page=1&order=%s&sort=%s' %(self.appid, self.country, self.app_status_str, self.app_status_sdate, self.app_status_edate, self.app_status_order, self.app_status_sort)
+            headers = {
+                'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.125 Safari/537.36',
+                'content-type': 'application/x-www-form-urlencoded; charset=UTF-8'
+            }
+            res = session.post(url, data=payload, headers=headers)
+            self.app_status_list.append(res.json())
+            page_num += 1
+            if page_num > res.json()['maxPage']:
+                break
+        return self.app_status_list
+
+    def get_new_status_info(self):
+        self.get_status_appStatusList()
+        for status_list in self.app_status_list:
+            if status_list['msg'] == '成功':
+                if len(status_list['data']) > 0:
+                    sdate_time = status_list['data'][0]['sdate']
+                    return sdate_time
+                else:
+                    return ''
+            return ''
+
+    def get_old_status_info(self):
+        self.get_status_appStatusList()
+        for status_list in self.app_status_list:
+            if status_list['msg'] == '成功':
+                if len(status_list['data']) > 0:
+                    sdate_time = status_list['data'][-1]['sdate']
+                    return sdate_time
+                else:
+                    return ''
+            return ''
+
+
+
+
 
 
 
